#define PATH "/apps/camorama/preferences"
#define KEY_DEVICE PATH "/device"
#define KEY1 "/apps/camorama/preferences/save_dir"
#define KEY2 "/apps/camorama/preferences/save_file"
#define KEY3 "/apps/camorama/preferences/file_type"
#define KEY4 "/apps/camorama/preferences/timestamp"
#define KEY5 "/apps/camorama/preferences/hostname"
#define KEY6 "/apps/camorama/preferences/login"
#define KEY7 "/apps/camorama/preferences/password"
#define KEY8 "/apps/camorama/preferences/remote_save_dir"
#define KEY9 "/apps/camorama/preferences/remote_save_file"
#define KEY10 "/apps/camorama/preferences/remote_file_type"
#define KEY11 "/apps/camorama/preferences/remote_timestamp"
#define KEY12 "/apps/camorama/preferences/local_capture"
#define KEY13 "/apps/camorama/preferences/remote_capture"
#define KEY14 "/apps/camorama/preferences/append_ts_to_file"
#define KEY15 "/apps/camorama/preferences/remote_append_ts_to_file"
#define KEY16 "/apps/camorama/preferences/timestamp_string"
#define KEY17 "/apps/camorama/preferences/date_format"
#define KEY18 "/apps/camorama/preferences/use_custom_string"
#define KEY19 "/apps/camorama/preferences/drawdate"
#define KEY20 "/apps/camorama/preferences/auto_capture"
#define KEY21 "/apps/camorama/preferences/auto_capture_interval"
#define KEY22 "/apps/camorama/preferences/show_adjustments"
#define KEY23 "/apps/camorama/preferences/show_effects"
